# Generated by Django 2.0.6 on 2018-06-28 20:15

from django.db import migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('openid_connect_op', '0007_auto_20180501_0632'),
    ]

    operations = [
        migrations.AlterField(
            model_name='openidagreement',
            name='allowed_claims',
            field=jsonfield.fields.JSONField(default=[], verbose_name='List of allowed claims for this agreement'),
        ),
    ]
