# -*- coding: utf-8 -*-
# Generated by Django 1.11.7 on 2017-12-04 19:48
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('openid_connect_op', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='openidclient',
            name='client_code',
            field=models.CharField(blank=True, max_length=32, null=True),
        ),
    ]
