# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-01-02 18:55
from __future__ import unicode_literals

from django.db import migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('openid_connect_op', '0002_openidclient_client_code'),
    ]

    operations = [
        migrations.AddField(
            model_name='openidclient',
            name='client_registration_data',
            field=jsonfield.fields.JSONField(default={}),
        ),
    ]
