# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-01-03 15:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('openid_connect_op', '0005_auto_20180103_0908'),
    ]

    operations = [
        migrations.AlterField(
            model_name='openidclient',
            name='jwks',
            field=models.TextField(default='{}'),
        ),
    ]
