# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-05-01 11:32
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('openid_connect_op', '0006_auto_20180103_0922'),
    ]

    operations = [
        migrations.AlterField(
            model_name='openidclient',
            name='sub_hash',
            field=models.CharField(blank=True, max_length=256, null=True, verbose_name='If set, &lt;&lt;sub&gt;&gt; values (that is, username) will be concatenated with this value and sha256'),
        ),
    ]
