# Generated by Django 2.1.5 on 2019-01-28 17:49
from django.db import migrations
import jsonfield.fields



class Migration(migrations.Migration):

    dependencies = [
        ('openid_connect_op', '0008_auto_20180628_2215'),
    ]

    operations = [
        migrations.AlterField(
            model_name='openidagreement',
            name='allowed_scopes',
            field=jsonfield.fields.JSONField(default=[], verbose_name='List of allowed scopes for this agreement.'),
        ),
    ]
