# Generated by Django 2.1.5 on 2019-01-28 17:51

from django.db import migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('openid_connect_op', '0011_auto_20190128_1850'),
    ]

    operations = [
        migrations.AlterField(
            model_name='openidclient',
            name='client_registration_data',
            field=jsonfield.fields.JSONField(default=dict),
        ),
    ]
