# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-01-03 15:08
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('openid_connect_op', '0004_openidclient_jwks'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='openidkey',
            name='client',
        ),
        migrations.DeleteModel(
            name='OpenIDKey',
        ),
    ]
